@@ -252,7 +252,7 @@ class HydraPy:
             self._message_handler = message_handler
 
         if queue_handler:
-            self._queue_handler = message_handler
+            self._queue_handler = queue_handler
 
         with open(config_path, 'r', encoding='utf-8-sig') as json_file:
             self._config = json.load(json_file)
